function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var hljs = _interopDefault(require('highlight.js'));
var prettyBytes = _interopDefault(require('pretty-bytes'));
var classNames = _interopDefault(require('classnames'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var styles = {"container":"_1Lxpd","header":"_1aDvk","body":"_2mo3X","num":"_1H33u","code":"_1NqbF","codeInner":"_2Dc72","highlighted":"_CLeTf"};

var NumberCell = (function (_ref) {
  var lineNumber = _ref.lineNumber,
      onClick = _ref.onClick;
  return React.createElement("td", {
    id: "L" + lineNumber,
    key: "col-line-number-" + lineNumber,
    "data-line-number": lineNumber,
    className: styles.num,
    onClick: onClick
  });
});

var CodeCell = (function (_ref) {
  var lineNumber = _ref.lineNumber,
      code = _ref.code,
      isHighlight = _ref.isHighlight;

  var _React$useState = React.useState(styles.code + " " + styles.codeInner),
      className = _React$useState[0],
      setClassName = _React$useState[1];

  React.useEffect(function () {
    var _classNames;

    setClassName(classNames(styles.code, styles.codeInner, (_classNames = {}, _classNames[styles.highlighted] = isHighlight, _classNames)));
  }, [isHighlight]);
  return React.createElement("td", {
    id: "LC" + lineNumber,
    key: "col-code-" + lineNumber,
    className: className,
    dangerouslySetInnerHTML: {
      __html: code
    }
  });
});

var Row = (function (_ref) {
  var row = _ref.row,
      showLineNumber = _ref.showLineNumber,
      onLineNumberClick = _ref.onLineNumberClick;
  var lineNumber = row.lineNumber;

  var handleClick = function handleClick(event) {
    onLineNumberClick && onLineNumberClick(lineNumber, event);
  };

  return React.createElement("tr", null, showLineNumber && React.createElement(NumberCell, {
    lineNumber: lineNumber,
    onClick: handleClick
  }), React.createElement(CodeCell, {
    lineNumber: lineNumber,
    code: row.content,
    isHighlight: row.isHighlight
  }));
});

var CodeContainer = React.memo(function (_ref) {
  var code = _ref.code,
      language = _ref.language,
      _ref$showLineNumber = _ref.showLineNumber,
      showLineNumber = _ref$showLineNumber === void 0 ? true : _ref$showLineNumber,
      _ref$selectedLines = _ref.selectedLines,
      selectedLines = _ref$selectedLines === void 0 ? [] : _ref$selectedLines,
      onLineNumberClick = _ref.onLineNumberClick,
      onUnSelect = _ref.onUnSelect;

  var _React$useState = React.useState([]),
      rows = _React$useState[0],
      setRows = _React$useState[1];

  var lines = rows.length;
  var handleUnSelect = React.useCallback(function (event) {
    if (event.key === 'Escape') {
      var newRows = codeToRows(code, language);
      setRows(newRows);
      onUnSelect && onUnSelect();
    }
  }, [code, language]);
  document.body.addEventListener('keydown', handleUnSelect);
  React.useEffect(function () {
    var newRows = codeToRows(code, language, selectedLines);
    setRows(newRows);
  }, [language, code]);
  var getSloc = React.useCallback(function () {
    return code.split('\n').filter(function (line) {
      return line.trim().length > 0;
    }).length;
  }, [code]);
  var getSize = React.useCallback(function () {
    return prettyBytes(new Blob([code]).size);
  }, [code]);

  var onClickNum = function onClickNum(lineNumber, event) {
    var newRows = [];
    var index = lineNumber - 1;
    var highlightedLines = rows.filter(function (row) {
      return row.isHighlight;
    });

    if (event.shiftKey) {
      var firstSelectedLine = highlightedLines[0];
      var range = firstSelectedLine.lineNumber - lineNumber;
      var _selectedLines = [lineNumber];
      var n = 0;

      while (n <= Math.abs(range)) {
        var _index = range > 0 ? lineNumber + n : lineNumber - n;

        _selectedLines.push(rows[_index - 1].lineNumber);

        n++;
      }

      newRows = rows.map(function (row) {
        return _extends({}, row, {
          isHighlight: !!_selectedLines.find(function (num) {
            return num === row.lineNumber;
          })
        });
      });
      setRows(newRows);
    } else {
      newRows = rows.map(function (row) {
        return _extends({}, row, {
          isHighlight: false
        });
      });
      newRows[index].isHighlight = true;
      setRows(newRows);
    }

    var selectedLines = newRows.filter(function (row) {
      return !!row.isHighlight;
    }).map(function (row) {
      return row.lineNumber;
    });
    onLineNumberClick && onLineNumberClick(lineNumber, selectedLines);
  };

  var renderRows = function renderRows() {
    return rows.map(function (row, index) {
      return React.createElement(Row, {
        key: "code-container-row-" + index,
        row: row,
        showLineNumber: showLineNumber,
        onLineNumberClick: onClickNum
      });
    });
  };

  return React.createElement("div", {
    className: styles.container
  }, React.createElement("div", {
    className: styles.header
  }, React.createElement("div", null, lines, " lines (", getSloc(), " sloc) | ", getSize())), React.createElement("div", {
    className: styles.body + " hljs"
  }, React.createElement("table", null, React.createElement("tbody", null, renderRows()))));
});

var codeToRows = function codeToRows(code, language, selectedLines) {
  var highlightedCodes = !!language && hljs.getLanguage(language || '') ? hljs.highlight(language, code).value : hljs.highlightAuto(code).value;
  return highlightedCodes.split('\n').map(function (content, index) {
    return {
      lineNumber: index + 1,
      content: content,
      isHighlight: selectedLines ? !!selectedLines.find(function (lineNumber) {
        return lineNumber === index + 1;
      }) : false
    };
  });
};

exports.CodeContainer = CodeContainer;
exports.default = CodeContainer;
//# sourceMappingURL=index.js.map
